@@ -4,7 +4,6 @@ use warnings;
 use lib;
 
 use File::Spec();
-use Cwd;
 use vars qw/$Base $VERSION @base/;
 use vars qw/$Script/; # compat
 
@@ -18,7 +17,7 @@ Version 1.01
 
 =cut
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 =head1 SYNOPSIS
 
@@ -94,7 +93,7 @@ the initial cwd (current working directory), which are the two pieces of
 information the module relies on to interpret the relative path given by the
 calling program.
 
-If one of cwd, or $0 is changed before Find::Lib has a chance to do
+If one of cwd, $ENV{PWD} or $0 is changed before Find::Lib has a chance to do
 its job, then Find::Lib will most probably die, saying "The script cannot be
 found". I don't know a workaround that. So be sure to load Find::Lib as soon
 as possible in your script to minimize problems (you are in control!).
@@ -128,8 +127,16 @@ sub guess_base {
     return guess_system_path();
 }
 
+## we want to use PWD if it exists (it's not guaranteed on all platforms)
+## so that we have a sense of the shell current working dir, with unresolved
+## symlinks
+sub guess_pwd {
+    return $ENV{PWD} || Cwd::cwd();
+}
+
 sub guess_shell_path {
-    my ($volume, $path, $file) = File::Spec->splitpath( Cwd::cwd() );
+    my $pwd = guess_pwd();
+    my ($volume, $path, $file) = File::Spec->splitpath($pwd);
     my @path = File::Spec->splitdir($path);
     pop @path unless $path[-1];
     @base = (@path, $file);
